@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: m3Func.php 4606 2012-01-21 14:21:00Z fishbone $
+ * @version    SVN: $Id: m3Func.php 4893 2012-04-30 12:32:30Z fishbone $
  * @link       http://www.magic3.org
  */
 /**
@@ -826,13 +826,18 @@ function getRFC822Date($src = NULL)
 /**
  * 簡易版デバッグ出力
  *
- * @param string $msg			出力メッセージ
+ * @param mixed $msg			string型のとき=出力メッセージ、それ以外のとき=出力変数
  * @return なし
  */
 function debug($msg)
 {
 	global $gLogManager;
-	$gLogManager->debug(__METHOD__, $msg);
+	
+	if (is_string($msg)){
+		$gLogManager->debug(__METHOD__, $msg);
+	} else {
+		$gLogManager->debug(__METHOD__, var_export($msg, true));
+	}
 }
 /**
  * 簡易版デバッグ出力(時間付き)
