@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: textConvManager.php 5117 2012-08-18 09:00:10Z fishbone $
+ * @version    SVN: $Id: textConvManager.php 5153 2012-09-03 01:59:21Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/htmlEdit.php');
@@ -134,7 +134,7 @@ class TextConvManager extends Core
 					break;
 				case 'CT_CREATE_DT':			// コンテンツ作成日時
 				case 'CT_UPDATE_DT':			// コンテンツ更新日時
-				case 'CT_REGIST_DT':			// コンテンツ記録日時
+				case 'CT_REGIST_DT':			// コンテンツ登録日時
 					$value = $this->contentInfo[$typeTag];
 					if (!empty($value)){
 						if (empty($format)){
@@ -144,6 +144,26 @@ class TextConvManager extends Core
 						}
 					}
 					break;
+				case 'CT_DATE':					// コンテンツ登録日
+					$value = $this->contentInfo[$typeTag];
+					if (!empty($value)){
+						if (empty($format)){
+							$destTag = date(M3_VIEW_FORMAT_DATE, strtotime($value));
+						} else {
+							$destTag = date($format, strtotime($value));
+						}
+					}
+					break;
+				case 'CT_TIME':					// コンテンツ登録時
+					$value = $this->contentInfo[$typeTag];
+					if (!empty($value)){
+						if (empty($format)){
+							$destTag = date(M3_VIEW_FORMAT_TIME, strtotime($value));
+						} else {
+							$destTag = date($format, strtotime($value));
+						}
+					}
+					break;
 				case 'CT_ID':		// コンテンツID
 				case 'CT_TITLE':		// コンテンツタイトル
 				default:
