@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2011 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: insert_base.sql 4996 2012-06-28 03:42:28Z fishbone $
+-- * @version    SVN: $Id: insert_base.sql 5156 2012-09-04 00:03:59Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -22,7 +22,7 @@
 INSERT INTO _system_config 
 (sc_id,                          sc_value,                  sc_name) VALUES
 ('system_name',                 'Magic3',                   'システム名称'),
-('db_version',                  '2012032701',               'DBバージョン'),
+('db_version',                  '2012051201',               'DBバージョン'),
 ('server_id',                   '',                         'サーバ識別用ID'),
 ('server_url',                  '',                         'サーバURL'),
 ('default_lang',                'ja',                       'デフォルト言語'),
@@ -146,29 +146,29 @@ INSERT INTO _nav_item
 
 -- ページIDマスター
 INSERT INTO _page_id 
-(pg_id,          pg_type, pg_default_sub_id, pg_path,       pg_name,                            pg_description,                       pg_priority, pg_device_type, pg_active, pg_visible, pg_mobile, pg_editable) VALUES
-('index',        0,       'content',         'index',       'PC用アクセスポイント',             'PC用アクセスポイント',               0,           0,              true,      true,      false,     true),
-('s_index',      0,       'front',         's/index',     'スマートフォン用アクセスポイント', 'スマートフォン用アクセスポイント',   1,           2,              true,      true,      false,     true),
-('m_index',      0,       'front',         'm/index',     '携帯用アクセスポイント',           '携帯用アクセスポイント',             2,           1,              true,      true,      true,      true),
-('admin_index',  0,       'content',         'admin/index', '管理用アクセスポイント',           '管理用アクセスポイント',             3,           0,              true,      true,      false,     false),
-('connector',    0,       'content',         'connector',   'サーバ接続用アクセスポイント',     'サーバ接続用アクセスポイント',       4,           0,              true,      true,      false,     true),
-('front',        1,       '',                '',            'トップ専用',                       'トップ専用画面用',                   0,           0,              true,      true,      false,     true),
-('content',      1,       '',                '',            'コンテンツ',                       'コンテンツ画面用',                   1,           0,              true,      true,      false,     false),
-('shop',         1,       '',                '',            'ECショップ',                       'ECショップ画面用',                   2,           0,              true,      true,      false,     true),
-('shop_safe',    1,       '',                '',            'ECショップ(セキュリティ保護)',     'ECショップ(セキュリティ保護)画面用', 3,           0,              true,      true,      false,     true),
-('bbs',          1,       '',                '',            '掲示板',                           '掲示板画面用',                       4,           0,              true,      true,      false,     true),
-('blog',         1,       '',                '',            'ブログ',                           'ブログ画面用',                       5,           0,              true,      true,      false,     true),
-('wiki',         1,       '',                '',            'Wiki',                             'Wiki画面用',                         6,           0,              true,      true,      false,     true),
-('event',        1,       '',                '',            'イベント',                         'イベント画面用',                     7,           0,              true,      true,      false,     true),
-('photo',        1,       '',                '',            'フォトギャラリー',                   'フォトギャラリー画面用',               8,           0,              true,      true,      false,     true),
-('contact',      1,       '',                '',            'お問い合わせ',                     'お問い合わせ画面用',                 9,           0,              true,      true,      false,     true),
-('contact2',     1,       '',                '',            'お問い合わせ2',                    'お問い合わせ画面用',                 10,          0,              true,      true,      false,     true),
-('contact3',     1,       '',                '',            'お問い合わせ3',                    'お問い合わせ画面用',                 11,          0,              true,      true,      false,     true),
-('reserve',      1,       '',                '',            '予約',                             '予約画面用',                         20,          0,              true,      true,      false,     true),
-('search',       1,       '',                '',            '検索',                             '検索画面用',                         21,          0,              true,      true,      false,     true),
-('user',         1,       '',                '',            'ユーザコンテンツ',                 'ユーザ作成コンテンツ用',             50,          0,              true,      true,      false,     true),
-('deploy',       1,       '',                '',            'ウィジェット有効化用',             'ウィジェット有効化用',               100,         0,              true,      false,     false,     true),
-('test',         1,       '',                '',            'ウィジェットテスト用',             'ウィジェットテスト用非公開画面',     101,         0,              false,     true,      false,     true);
+(pg_id,          pg_type, pg_default_sub_id, pg_path,       pg_name,                            pg_description,                       pg_priority, pg_device_type, pg_active, pg_visible, pg_mobile, pg_editable, pg_admin_menu, pg_analytics) VALUES
+('index',        0,       'content',         'index',       'PC用アクセスポイント',             'PC用アクセスポイント',               0,           0,              true,      true,      false,     true, true, true),
+('s_index',      0,       'front',         's/index',     'スマートフォン用アクセスポイント', 'スマートフォン用アクセスポイント',   1,           2,              true,      true,      false,     true, false, true),
+('m_index',      0,       'front',         'm/index',     '携帯用アクセスポイント',           '携帯用アクセスポイント',             2,           1,              true,      true,      true,      true, false, true),
+('admin_index',  0,       'content',         'admin/index', '管理用アクセスポイント',           '管理用アクセスポイント',             3,           0,              true,      true,      false,     false, false, false),
+('connector',    0,       'content',         'connector',   'サーバ接続用アクセスポイント',     'サーバ接続用アクセスポイント',       4,           0,              true,      true,      false,     true, false, false),
+('front',        1,       '',                '',            'トップ専用',                       'トップ専用画面用',                   0,           0,              true,      true,      false,     true, false, false),
+('content',      1,       '',                '',            'コンテンツ',                       'コンテンツ画面用',                   1,           0,              true,      true,      false,     false, false, false),
+('shop',         1,       '',                '',            'ECショップ',                       'ECショップ画面用',                   2,           0,              true,      true,      false,     true, false, false),
+('shop_safe',    1,       '',                '',            'ECショップ(セキュリティ保護)',     'ECショップ(セキュリティ保護)画面用', 3,           0,              true,      true,      false,     true, false, false),
+('bbs',          1,       '',                '',            '掲示板',                           '掲示板画面用',                       4,           0,              true,      true,      false,     true, false, false),
+('blog',         1,       '',                '',            'ブログ',                           'ブログ画面用',                       5,           0,              true,      true,      false,     true, false, false),
+('wiki',         1,       '',                '',            'Wiki',                             'Wiki画面用',                         6,           0,              true,      true,      false,     true, false, false),
+('event',        1,       '',                '',            'イベント',                         'イベント画面用',                     7,           0,              true,      true,      false,     true, false, false),
+('photo',        1,       '',                '',            'フォトギャラリー',                   'フォトギャラリー画面用',               8,           0,              true,      true,      false,     true, false, false),
+('contact',      1,       '',                '',            'お問い合わせ',                     'お問い合わせ画面用',                 9,           0,              true,      true,      false,     true, false, false),
+('contact2',     1,       '',                '',            'お問い合わせ2',                    'お問い合わせ画面用',                 10,          0,              true,      true,      false,     true, false, false),
+('contact3',     1,       '',                '',            'お問い合わせ3',                    'お問い合わせ画面用',                 11,          0,              true,      true,      false,     true, false, false),
+('reserve',      1,       '',                '',            '予約',                             '予約画面用',                         20,          0,              true,      true,      false,     true, false, false),
+('search',       1,       '',                '',            '検索',                             '検索画面用',                         21,          0,              true,      true,      false,     true, false, false),
+('user',         1,       '',                '',            'ユーザコンテンツ',                 'ユーザ作成コンテンツ用',             50,          0,              true,      true,      false,     true, false, false),
+('deploy',       1,       '',                '',            'ウィジェット有効化用',             'ウィジェット有効化用',               100,         0,              true,      false,     false,     true, false, false),
+('test',         1,       '',                '',            'ウィジェットテスト用',             'ウィジェットテスト用非公開画面',     101,         0,              false,     true,      false,     true, false, false);
 
 -- ページ情報マスター
 INSERT INTO _page_info
