@@ -10,12 +10,12 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: blog_calendar_boxWidgetContainer.php 4750 2012-03-13 12:58:39Z fishbone $
+ * @version    SVN: $Id: blog_calendar_boxWidgetContainer.php 5053 2012-07-23 02:49:46Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath()		. '/baseWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetDbPath()	. '/blog_calendar_boxDb.php');
-require_once($gEnvManager->getLibPath()			. '/Calendar-0.5.3/Month/Weekdays.php');
+require_once(CALENDAR_ROOT			. 'Month/Weekdays.php');
 
 class blog_calendar_boxWidgetContainer extends BaseWidgetContainer
 {
