@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2011 Magic3 Project.
+ * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: blog_mainEntryWidgetContainer.php 4063 2011-04-08 08:47:16Z fishbone $
+ * @version    SVN: $Id: blog_mainEntryWidgetContainer.php 5145 2012-08-29 13:21:42Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/blog_mainBaseWidgetContainer.php');
@@ -18,8 +18,6 @@ require_once($gEnvManager->getCurrentWidgetDbPath() .	'/blog_mainDb.php');
 
 class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 {
-	private $db;	// DB接続オブジェクト
-	private $sysDb;		// システムDBオブジェクト
 	private $serialNo;		// 選択中の項目のシリアル番号
 	private $entryId;
 	private $blogId;		// 所属ブログ
@@ -45,10 +43,6 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 	{
 		// 親クラスを呼び出す
 		parent::__construct();
-		
-		// DBオブジェクト作成
-		$this->db = new blog_mainDb();
-		$this->sysDb = $this->gInstance->getSytemDbObject();
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -144,7 +138,7 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 		
 		// DBの保存設定値を取得
 		$maxListCount = self::DEFAULT_LIST_COUNT;
-		$serializedParam = $this->sysDb->getWidgetParam($this->gEnv->getCurrentWidgetId());
+		$serializedParam = $this->_db->getWidgetParam($this->gEnv->getCurrentWidgetId());
 		if (!empty($serializedParam)){
 			$dispInfo = unserialize($serializedParam);
 			$maxListCount = $dispInfo->maxMemberListCountByAdmin;		// リスト最大表示数
@@ -179,7 +173,7 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 				// 削除するブログ記事の情報を取得
 				$delEntryInfo = array();
 				for ($i = 0; $i < count($delItems); $i++){
-					$ret = $this->db->getEntryBySerial($delItems[$i], $row, $categoryRow);
+					$ret = self::$_mainDb->getEntryBySerial($delItems[$i], $row, $categoryRow);
 					if ($ret){
 						$newInfoObj = new stdClass;
 						$newInfoObj->entryId = $row['be_id'];		// 記事ID
@@ -188,7 +182,7 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 					}
 				}
 				
-				$ret = $this->db->delEntryItem($delItems);
+				$ret = self::$_mainDb->delEntryItem($delItems);
 				if ($ret){		// データ削除成功のとき
 					$this->setGuidanceMsg('データを削除しました');
 					
@@ -220,7 +214,7 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 		if (!empty($search_endDt)) $endDt = $this->getNextDay($search_endDt);
 		
 		// 総数を取得
-		$totalCount = $this->db->getEntryItemCount($search_startDt, $endDt, $this->categoryArray, $search_keyword, $this->langId, $this->blogId);
+		$totalCount = self::$_mainDb->getEntryItemCount($search_startDt, $endDt, $this->categoryArray, $search_keyword, $this->langId, $this->blogId);
 
 		// 表示するページ番号の修正
 		$pageCount = (int)(($totalCount -1) / $maxListCount) + 1;		// 総ページ数
@@ -242,11 +236,11 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 		}
 		
 		// 記事項目リストを取得
-		$this->db->searchEntryItems($maxListCount, $pageNo, $search_startDt, $endDt, $this->categoryArray, $search_keyword, $this->langId, array($this, 'itemListLoop'), $this->blogId);
+		self::$_mainDb->searchEntryItems($maxListCount, $pageNo, $search_startDt, $endDt, $this->categoryArray, $search_keyword, $this->langId, array($this, 'itemListLoop'), $this->blogId);
 		if (count($this->serialArray) <= 0) $this->tmpl->setAttribute('itemlist', 'visibility', 'hidden');// 投稿記事がないときは、一覧を表示しない
 		
 		// カテゴリーメニューを作成
-		$this->db->getAllCategory($this->langId, $this->categoryListData);
+		self::$_mainDb->getAllCategory($this->langId, $this->categoryListData);
 		$this->createCategoryMenu(1);		// メニューは１つだけ表示
 		
 		// 検索結果
@@ -277,8 +271,8 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 		//$regDt			= date("Y/m/d H:i:s");						// 投稿日時
 		
 		// ブログ定義値
-		$useMultiBlog = $this->_configArray[self::CF_USE_MULTI_BLOG];// マルチブログを使用するかどうか
-		$this->categoryCount = $this->_configArray[self::CF_CATEGORY_COUNT];			// カテゴリ数
+		$useMultiBlog = $this->_configArray[blog_mainCommonDef::CF_USE_MULTI_BLOG];// マルチブログを使用するかどうか
+		$this->categoryCount = $this->_configArray[blog_mainCommonDef::CF_CATEGORY_COUNT];			// カテゴリ数
 		if (empty($this->categoryCount)) $this->categoryCount = self::DEFAULT_CATEGORY_COUNT;
 		
 		$openBy = $request->trimValueOf(M3_REQUEST_PARAM_OPEN_BY);		// ウィンドウオープンタイプ
@@ -338,7 +332,7 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 			//if ($act == 'select') $this->langId = $defaultLangId;		// 言語は一旦リセット
 			
 			// 登録済みのブログ記事を取得
-			//$this->serialNo = $this->db->getEntrySerialNoByContentId($this->entryId, $this->langId);
+			//$this->serialNo = self::$_mainDb->getEntrySerialNoByContentId($this->entryId, $this->langId);
 			//if (empty($this->serialNo)){
 			//	// 取得できないときは初期化
 			//	$dataInit = true;		// データ初期化
@@ -347,7 +341,7 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 			//}
 		} else if ($act == 'selectlang'){		// 項目選択の場合
 			// 登録済みのコンテンツデータを取得
-			$this->serialNo = $this->db->getEntrySerialNoByContentId($this->entryId, $this->langId);
+			$this->serialNo = self::$_mainDb->getEntrySerialNoByContentId($this->entryId, $this->langId);
 			if (empty($this->serialNo)){
 				// 取得できないときは一部初期化
 				//$name = '';				// タイトル
@@ -386,10 +380,10 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 				
 				$regDt = $this->convertToProperDate($entry_date) . ' ' . $this->convertToProperTime($entry_time);		// 投稿日時
 				if ($act == 'add'){
-					$ret = $this->db->addEntryItem(0, $this->langId, $name, $html, $html2, $status, $this->categoryArray, $this->blogId, 
+					$ret = self::$_mainDb->addEntryItem(0, $this->langId, $name, $html, $html2, $status, $this->categoryArray, $this->blogId, 
 													$regUserId, $regDt, $startDt, $endDt, $showComment, $receiveComment, $newSerial);
 				} else {
-					$ret = $this->db->addEntryItem($this->entryId, $this->langId, $name, $html, $html2, $status, $this->categoryArray, $this->blogId, 
+					$ret = self::$_mainDb->addEntryItem($this->entryId, $this->langId, $name, $html, $html2, $status, $this->categoryArray, $this->blogId, 
 													$regUserId, $regDt, $startDt, $endDt, $showComment, $receiveComment, $newSerial);
 				}
 				if ($ret){
@@ -407,7 +401,7 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 					
 					// 運用ログを残す
 					$statusStr = '';
-					$ret = $this->db->getEntryBySerial($this->serialNo, $row, $categoryRow);
+					$ret = self::$_mainDb->getEntryBySerial($this->serialNo, $row, $categoryRow);
 					if ($ret){
 						$this->entryId = $row['be_id'];		// 記事ID
 						$name = $row['be_name'];		// コンテンツ名前
@@ -450,7 +444,7 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 				}
 				
 				$regDt = $this->convertToProperDate($entry_date) . ' ' . $this->convertToProperTime($entry_time);		// 投稿日時
-				$ret = $this->db->updateEntryItem($this->serialNo, $name, $html, $html2, $status, $this->categoryArray, $this->blogId, 
+				$ret = self::$_mainDb->updateEntryItem($this->serialNo, $name, $html, $html2, $status, $this->categoryArray, $this->blogId, 
 													''/*投稿者そのまま*/, $regDt, $startDt, $endDt, $showComment, $receiveComment, $newSerial);
 				if ($ret){
 					$this->setGuidanceMsg('データを更新しました');
@@ -467,7 +461,7 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 					
 					// 運用ログを残す
 					$statusStr = '';
-					$ret = $this->db->getEntryBySerial($this->serialNo, $row, $categoryRow);
+					$ret = self::$_mainDb->getEntryBySerial($this->serialNo, $row, $categoryRow);
 					if ($ret){
 						$this->entryId = $row['be_id'];		// 記事ID
 						$name = $row['be_name'];		// コンテンツ名前
@@ -491,13 +485,13 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 			// エラーなしの場合は、データを削除
 			if ($this->getMsgCount() == 0){
 				// 削除するブログ記事の情報を取得
-				$ret = $this->db->getEntryBySerial($this->serialNo, $row, $categoryRow);
+				$ret = self::$_mainDb->getEntryBySerial($this->serialNo, $row, $categoryRow);
 				if ($ret){
 					$this->entryId = $row['be_id'];		// 記事ID
 					$name = $row['be_name'];		// コンテンツ名前
 				}
 				
-				$ret = $this->db->delEntryItem(array($this->serialNo));
+				$ret = self::$_mainDb->delEntryItem(array($this->serialNo));
 				if ($ret){		// データ削除成功のとき
 					$this->setGuidanceMsg('データを削除しました');
 					
@@ -520,13 +514,13 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 			// エラーなしの場合は、データを削除
 			if ($this->getMsgCount() == 0){
 				// 削除するブログ記事の情報を取得
-				$ret = $this->db->getEntryBySerial($this->serialNo, $row, $categoryRow);
+				$ret = self::$_mainDb->getEntryBySerial($this->serialNo, $row, $categoryRow);
 				if ($ret){
 					$this->entryId = $row['be_id'];		// 記事ID
 					$name = $row['be_name'];		// コンテンツ名前
 				}
 				
-				$ret = $this->db->delEntryItemById($this->serialNo);
+				$ret = self::$_mainDb->delEntryItemById($this->serialNo);
 				if ($ret){		// データ削除成功のとき
 					$this->setGuidanceMsg('データを削除しました');
 					
@@ -555,7 +549,7 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 		
 		// 設定データを再取得
 		if ($dataReload){		// データの再ロード
-			$ret = $this->db->getEntryBySerial($this->serialNo, $row, $categoryRow);
+			$ret = self::$_mainDb->getEntryBySerial($this->serialNo, $row, $categoryRow);
 			if ($ret){
 				$this->entryId = $row['be_id'];		// 記事ID
 				$this->blogId = $row['be_blog_id'];		// 所属ブログ
@@ -582,7 +576,7 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 			}
 		}
 		// カテゴリーメニューを作成
-		$this->db->getAllCategory($this->langId, $this->categoryListData);
+		self::$_mainDb->getAllCategory($this->langId, $this->categoryListData);
 		$this->createCategoryMenu($this->categoryCount);
 		
 		// 所属ブログ
@@ -650,7 +644,7 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 			}
 			// 言語選択メニュー作成
 			//if (!empty($this->entryId)){	// コンテンツが選択されているとき
-			//	$this->db->getAllLang(array($this, 'langLoop'));
+			//	self::$_mainDb->getAllLang(array($this, 'langLoop'));
 			//	$this->tmpl->setAttribute('select_lang', 'visibility', 'visible');
 			//}
 		}
@@ -676,7 +670,7 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 
 		// カテゴリーを取得
 		$categoryArray = array();
-		$ret = $this->db->getEntryBySerial($serial, $row, $categoryRow);
+		$ret = self::$_mainDb->getEntryBySerial($serial, $row, $categoryRow);
 		if ($ret){
 			for ($i = 0; $i < count($categoryRow); $i++){
 				if (function_exists('mb_strimwidth')){
@@ -825,7 +819,7 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 	 */
 	function getBlogName($blogId)
 	{
-		$ret = $this->db->getBlogInfoById($blogId, $row);
+		$ret = self::$_mainDb->getBlogInfoById($blogId, $row);
 		if ($ret){
 			return $row['bl_name'];
 		} else {
@@ -849,7 +843,7 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 		$this->tmpl->addVars('blogid_list', $row);
 		$this->tmpl->parseTemplate('blogid_list', 'a');
 				
-		$ret = $this->db->getAllBlogId($rows);
+		$ret = self::$_mainDb->getAllBlogId($rows);
 		if ($ret){
 			for ($i = 0; $i < count($rows); $i++){
 				$selected = '';
@@ -895,7 +889,7 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 	 */
 	function clearCacheBySerial($serial)
 	{
-		$ret = $this->db->getEntryBySerial($serial, $row, $categoryRow);// 記事ID取得
+		$ret = self::$_mainDb->getEntryBySerial($serial, $row, $categoryRow);// 記事ID取得
 		if ($ret){
 			$entryId = $row['be_id'];		// 記事ID
 			$urlParam = array();
