@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: blog_mainTopWidgetContainer.php 5148 2012-09-03 01:39:15Z fishbone $
+ * @version    SVN: $Id: blog_mainTopWidgetContainer.php 5157 2012-09-05 06:41:45Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/blog_mainBaseWidgetContainer.php');
@@ -441,12 +441,16 @@ class blog_mainTopWidgetContainer extends blog_mainBaseWidgetContainer
 		}
 
 		if ($showTopContent){		// トップコンテンツを表示するとき
-			// トップコンテンツを表示
+			// トップコンテンツを表示。トップコンテンツがない場合はブログ記事表示
 			$topContent = self::$_configArray[blog_mainCommonDef::CF_MULTI_BLOG_TOP_CONTENT];// マルチブログ用トップコンテンツ
-			
-			$this->tmpl->setAttribute('show_top_content', 'visibility', 'visible');
-			$this->tmpl->addVar("show_top_content", "content", $topContent);
-		} else {
+			if (empty($topContent)){
+				$showTopContent = false;
+			} else {
+				$this->tmpl->setAttribute('show_top_content', 'visibility', 'visible');
+				$this->tmpl->addVar("show_top_content", "content", $topContent);
+			}
+		}
+		if (!$showTopContent){
 			// 総数を取得
 			$totalCount = self::$_mainDb->getEntryItemsCount($this->now, $this->startDt, $this->endDt, $this->_langId, $targetBlogId);
 
@@ -466,13 +470,16 @@ class blog_mainTopWidgetContainer extends blog_mainBaseWidgetContainer
 					$this->tmpl->setAttribute('page_link', 'visibility', 'visible');		// リンク表示
 					$this->tmpl->addVar("page_link", "page_link", $pageLink);
 				}
+			} else {	// ブログ記事データがないときはデータなしメッセージ追加
+				$this->title = self::MESSAGE_NO_ENTRY_TITLE;
+				$this->message = self::MESSAGE_NO_ENTRY;			// ユーザ向けメッセージ
 			}
 		}
 		// ブログ記事データがないときはデータなしメッセージ追加
-		if (!$showTopContent && !$this->isExistsViewData){
+/*		if (!$showTopContent && !$this->isExistsViewData){
 			$this->title = self::MESSAGE_NO_ENTRY_TITLE;
 			$this->message = self::MESSAGE_NO_ENTRY;			// ユーザ向けメッセージ
-		}
+		}*/
 	}
 	/**
 	 * 検索結果画面表示
