@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2011 Magic3 Project.
+ * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: blog_mainDb.php 4452 2011-11-14 12:59:37Z fishbone $
+ * @version    SVN: $Id: blog_mainDb.php 5146 2012-09-01 12:37:05Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -98,7 +98,7 @@ class blog_mainDb extends BaseDb
 			// 記事カテゴリー
 			$queryStr .=    'AND bw_category_id in (' . implode(",", $category) . ') ';
 		}
-		// 商品名、商品コード、説明を検索
+		// タイトル、本文、説明、ユーザ定義フィールドを検索
 		if (!empty($keyword)){
 			// 「'"\」文字をエスケープ
 			$keyword = addslashes($keyword);
@@ -106,7 +106,8 @@ class blog_mainDb extends BaseDb
 			$queryStr .=    'AND (be_name LIKE \'%' . $keyword . '%\' ';
 			$queryStr .=    'OR be_html LIKE \'%' . $keyword . '%\' ';
 			$queryStr .=    'OR be_html_ext LIKE \'%' . $keyword . '%\' ';
-			$queryStr .=    'OR be_description LIKE \'%' . $keyword . '%\') ';
+			$queryStr .=    'OR be_description LIKE \'%' . $keyword . '%\' ';
+			$queryStr .=    'OR be_option_fields LIKE \'%' . $keyword . '%\') ';	// ユーザ定義フィールド
 		}
 		
 		// 日付範囲
@@ -171,7 +172,7 @@ class blog_mainDb extends BaseDb
 			// 記事カテゴリー
 			$queryStr .=    'AND bw_category_id in (' . implode(",", $category) . ') ';
 		}
-		// 商品名、商品コード、説明を検索
+		// タイトル、本文、説明、ユーザ定義フィールドを検索
 		if (!empty($keyword)){
 			// 「'"\」文字をエスケープ
 			$keyword = addslashes($keyword);
@@ -179,7 +180,8 @@ class blog_mainDb extends BaseDb
 			$queryStr .=    'AND (be_name LIKE \'%' . $keyword . '%\' ';
 			$queryStr .=    'OR be_html LIKE \'%' . $keyword . '%\' ';
 			$queryStr .=    'OR be_html_ext LIKE \'%' . $keyword . '%\' ';
-			$queryStr .=    'OR be_description LIKE \'%' . $keyword . '%\') ';
+			$queryStr .=    'OR be_description LIKE \'%' . $keyword . '%\' ';
+			$queryStr .=    'OR be_option_fields LIKE \'%' . $keyword . '%\') ';	// ユーザ定義フィールド
 		}
 		
 		// 日付範囲
@@ -234,20 +236,21 @@ class blog_mainDb extends BaseDb
 		$initDt = $this->gEnv->getInitValueOfTimestamp();		// 日時初期化値
 		$params = array();
 		
-		//$queryStr = 'SELECT * FROM blog_entry ';
 		$queryStr  = 'SELECT * FROM blog_entry LEFT JOIN blog_id ON be_blog_id = bl_id AND bl_deleted = false ';
+		$queryStr .=   'LEFT JOIN _login_user ON be_regist_user_id = lu_id AND lu_deleted = false ';
 		$queryStr .=   'WHERE be_language_id = ? ';	$params[] = $langId;
 		$queryStr .=     'AND be_deleted = false ';		// 削除されていない
 		$queryStr .=     'AND be_regist_dt <= ? ';	$params[] = $now;	// 投稿日時が現在日時よりも過去のものを取得
 
-		// タイトルと記事を検索
+		// タイトルと記事、ユーザ定義フィールドを検索
 		if (!empty($keywords)){
 			for ($i = 0; $i < count($keywords); $i++){
 				$keyword = addslashes($keywords[$i]);// 「'"\」文字をエスケープ
 				$queryStr .=    'AND (be_name LIKE \'%' . $keyword . '%\' ';
 				$queryStr .=    'OR be_html LIKE \'%' . $keyword . '%\' ';
 				$queryStr .=    'OR be_html_ext LIKE \'%' . $keyword . '%\' ';
-				$queryStr .=    'OR be_description LIKE \'%' . $keyword . '%\') ';
+				$queryStr .=    'OR be_description LIKE \'%' . $keyword . '%\' ';
+				$queryStr .=    'OR be_option_fields LIKE \'%' . $keyword . '%\') ';	// ユーザ定義フィールド
 			}
 		}
 		
@@ -282,14 +285,15 @@ class blog_mainDb extends BaseDb
 		$queryStr .=    'AND be_deleted = false ';		// 削除されていない
 		$queryStr .=    'AND be_regist_dt <= ? ';	$params[] = $now;	// 投稿日時が現在日時よりも過去のものを取得
 
-		// タイトルと記事を検索
+		// タイトルと記事、ユーザ定義フィールドを検索
 		if (!empty($keywords)){
 			for ($i = 0; $i < count($keywords); $i++){
 				$keyword = addslashes($keywords[$i]);// 「'"\」文字をエスケープ
 				$queryStr .=    'AND (be_name LIKE \'%' . $keyword . '%\' ';
 				$queryStr .=    'OR be_html LIKE \'%' . $keyword . '%\' ';
 				$queryStr .=    'OR be_html_ext LIKE \'%' . $keyword . '%\' ';
-				$queryStr .=    'OR be_description LIKE \'%' . $keyword . '%\') ';
+				$queryStr .=    'OR be_description LIKE \'%' . $keyword . '%\' ';
+				$queryStr .=    'OR be_option_fields LIKE \'%' . $keyword . '%\') ';	// ユーザ定義フィールド
 			}
 		}
 		
@@ -304,10 +308,27 @@ class blog_mainDb extends BaseDb
 		$params[] = $now;
 		return $this->selectRecordCount($queryStr, $params);
 	}
+	/**
+	 * 次のエントリーIDを取得
+	 *
+	 * @return int							エントリーID
+	 */
+	function getNextEntryId()
+	{
+		// エントリーIDを決定する
+		$queryStr = 'SELECT MAX(be_id) AS mid FROM blog_entry ';
+		$ret = $this->selectRecord($queryStr, array(), $row);
+		if ($ret){
+			$entryId = $row['mid'] + 1;
+		} else {
+			$entryId = 1;
+		}
+		return $entryId;
+	}
 	/**
 	 * エントリー項目の新規追加
 	 *
-	 * @param string  $id			エントリーID
+	 * @param string  $id			エントリーID(0以下のときはエントリーIDを新規取得)
 	 * @param string  $langId		言語ID
 	 * @param string  $name			コンテンツ名
 	 * @param string  $html			HTML
@@ -319,12 +340,13 @@ class blog_mainDb extends BaseDb
 	 * @param timestamp $regDt		投稿日時
 	 * @param timestamp	$startDt	期間(開始日)
 	 * @param timestamp	$endDt		期間(終了日)
-	 * @param int     $newSerial	新規シリアル番号
 	 * @param bool    $showComment	コメントを表示するかどうか
 	 * @param bool $receiveComment	コメントを受け付けるかどうか
+	 * @param int     $newSerial	新規シリアル番号
+	 * @param array   $otherParams	その他のフィールド値
 	 * @return bool					true = 成功、false = 失敗
 	 */
-	function addEntryItem($id, $langId, $name, $html, $html2, $status, $category, $blogId, $regUserId, $regDt, $startDt, $endDt, $showComment, $receiveComment, &$newSerial)
+	function addEntryItem($id, $langId, $name, $html, $html2, $status, $category, $blogId, $regUserId, $regDt, $startDt, $endDt, $showComment, $receiveComment, &$newSerial, $otherParams = null)
 	{
 		$now = date("Y/m/d H:i:s");	// 現在日時
 		$userId = $this->gEnv->getCurrentUserId();	// 現在のユーザ
@@ -332,25 +354,31 @@ class blog_mainDb extends BaseDb
 		// トランザクション開始
 		$this->startTransaction();
 		
-		if ($id == 0){		// エントリーIDが0のときは、エントリーIDを新規取得
+		if (intval($id) <= 0){		// エントリーIDが0以下のときは、エントリーIDを新規取得
 			// エントリーIDを決定する
-			$queryStr = 'select max(be_id) as mid from blog_entry ';
+			$queryStr = 'SELECT MAX(be_id) AS mid FROM blog_entry ';
 			$ret = $this->selectRecord($queryStr, array(), $row);
 			if ($ret){
 				$entryId = $row['mid'] + 1;
 			} else {
 				$entryId = 1;
 			}
+			
+			// 新規記事追加のときは記事IDが変更されていないかチェック
+			if (intval($id) * (-1) != $entryId){
+				$this->endTransaction();
+				return false;
+			}
 		} else {
 			$entryId = $id;
 		}
 		
 		// 前レコードの削除状態チェック
 		$historyIndex = 0;
-		$queryStr = 'SELECT * FROM blog_entry ';
-		$queryStr .=  'WHERE be_id = ? ';
-		$queryStr .=    'AND be_language_id = ? ';
-		$queryStr .=  'ORDER BY be_history_index DESC ';
+		$queryStr  = 'SELECT * FROM blog_entry ';
+		$queryStr .=   'WHERE be_id = ? ';
+		$queryStr .=     'AND be_language_id = ? ';
+		$queryStr .=   'ORDER BY be_history_index DESC ';
 		$ret = $this->selectRecord($queryStr, array($entryId, $langId), $row);
 		if ($ret){
 			if (!$row['be_deleted']){		// レコード存在していれば終了
@@ -361,6 +389,9 @@ class blog_mainDb extends BaseDb
 		}
 		
 		// データを追加
+		$params = array($entryId, $langId, $historyIndex, $name, $html, $html2, $status, 
+												intval($showComment), intval($receiveComment), $blogId, $now, $regUserId, $regDt, $startDt, $endDt, $userId, $now);
+												
 		$queryStr  = 'INSERT INTO blog_entry ';
 		$queryStr .=   '(be_id, ';
 		$queryStr .=   'be_language_id, ';
@@ -378,15 +409,28 @@ class blog_mainDb extends BaseDb
 		$queryStr .=   'be_active_start_dt, ';
 		$queryStr .=   'be_active_end_dt, ';
 		$queryStr .=   'be_create_user_id, ';
-		$queryStr .=   'be_create_dt) ';
-		$queryStr .= 'VALUES ';
-		$queryStr .=   '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)';
-		$this->execStatement($queryStr, array($entryId, $langId, $historyIndex, $name, $html, $html2, $status, 
-												intval($showComment), intval($receiveComment), $blogId, $now, $regUserId, $regDt, $startDt, $endDt, $userId, $now));
+		$queryStr .=   'be_create_dt ';
+		
+		// その他のフィールド値を追加
+		$otherValueStr = '';
+		if (!empty($otherParams)){
+			$keys = array_keys($otherParams);// キーを取得
+			for ($i = 0; $i < count($keys); $i++){
+				$fieldName = $keys[$i];
+				$fieldValue = $otherParams[$fieldName];
+				if (!isset($fieldValue)) continue;
+				$params[] = $fieldValue;
+				$queryStr .= ', ' . $fieldName;
+				$otherValueStr .= ', ?';
+			}
+		}
+		$queryStr .=  ') VALUES ';
+		$queryStr .=   '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?' . $otherValueStr . ')';
+		$this->execStatement($queryStr, $params);
 		
 		// 新規のシリアル番号取得
 		$newSerial = 0;
-		$queryStr = 'select max(be_serial) as ns from blog_entry ';
+		$queryStr = 'SELECT MAX(be_serial) AS ns FROM blog_entry ';
 		$ret = $this->selectRecord($queryStr, array(), $row);
 		if ($ret) $newSerial = $row['ns'];
 		
@@ -420,9 +464,12 @@ class blog_mainDb extends BaseDb
 	 * @param bool    $showComment	コメントを表示するかどうか
 	 * @param bool $receiveComment	コメントを受け付けるかどうか
 	 * @param int     $newSerial	新規シリアル番号
+	 * @param array   $oldRecord	更新前の旧データ
+	 * @param array   $otherParams	その他のフィールド値
 	 * @return bool					true = 成功、false = 失敗
 	 */
-	function updateEntryItem($serial, $name, $html, $html2, $status, $category, $blogId, $regUserId, $regDt, $startDt, $endDt, $showComment, $receiveComment, &$newSerial)
+	function updateEntryItem($serial, $name, $html, $html2, $status, $category, $blogId, $regUserId, $regDt, $startDt, $endDt, $showComment, $receiveComment, &$newSerial, 
+								&$oldRecord, $otherParams = null)
 	{
 		$now = date("Y/m/d H:i:s");	// 現在日時
 		$userId = $this->gEnv->getCurrentUserId();	// 現在のユーザ
@@ -432,15 +479,17 @@ class blog_mainDb extends BaseDb
 		
 		// 指定のシリアルNoのレコードが削除状態でないかチェック
 		$historyIndex = 0;		// 履歴番号
-		$queryStr  = 'select * from blog_entry ';
-		$queryStr .=   'where be_serial = ? ';
-		$ret = $this->selectRecord($queryStr, array($serial), $row);
+		$queryStr  = 'SELECT * FROM blog_entry ';
+		$queryStr .=   'WHERE be_serial = ? ';
+		$ret = $this->selectRecord($queryStr, array(intval($serial)), $row);
 		if ($ret){		// 既に登録レコードがあるとき
 			if ($row['be_deleted']){		// レコードが削除されていれば終了
 				$this->endTransaction();
 				return false;
 			}
 			$historyIndex = $row['be_history_index'] + 1;
+			
+			$oldRecord = $row;			// 旧データ
 		} else {		// 存在しない場合は終了
 			$this->endTransaction();
 			return false;
@@ -451,7 +500,7 @@ class blog_mainDb extends BaseDb
 		$queryStr .=     'be_update_user_id = ?, ';
 		$queryStr .=     'be_update_dt = ? ';
 		$queryStr .=   'WHERE be_serial = ?';
-		$this->execStatement($queryStr, array($userId, $now, $serial));
+		$this->execStatement($queryStr, array($userId, $now, intval($serial)));
 		
 		// データを追加
 		if (empty($regUserId)){
@@ -467,7 +516,9 @@ class blog_mainDb extends BaseDb
 		$entryId = $row['be_id'];
 		$langId = $row['be_language_id'];
 		
-		// 新規レコード追加		
+		// 新規レコード追加
+		$params = array($entryId, $langId, $historyIndex, $name, $html, $html2, $status, 
+												intval($showComment), intval($receiveComment), $blogId, $now, $rUserId, $rDt, $startDt, $endDt, $userId, $now);
 		$queryStr  = 'INSERT INTO blog_entry ';
 		$queryStr .=   '(be_id, ';
 		$queryStr .=   'be_language_id, ';
@@ -485,15 +536,28 @@ class blog_mainDb extends BaseDb
 		$queryStr .=   'be_active_start_dt, ';
 		$queryStr .=   'be_active_end_dt, ';
 		$queryStr .=   'be_create_user_id, ';
-		$queryStr .=   'be_create_dt) ';
-		$queryStr .= 'VALUES ';
-		$queryStr .=   '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)';
-		$this->execStatement($queryStr, array($entryId, $langId, $historyIndex, $name, $html, $html2, $status, 
-												intval($showComment), intval($receiveComment), $blogId, $now, $rUserId, $rDt, $startDt, $endDt, $userId, $now));
+		$queryStr .=   'be_create_dt ';
+
+		// その他のフィールド値を追加
+		$otherValueStr = '';
+		if (!empty($otherParams)){
+			$keys = array_keys($otherParams);// キーを取得
+			for ($i = 0; $i < count($keys); $i++){
+				$fieldName = $keys[$i];
+				$fieldValue = $otherParams[$fieldName];
+				if (!isset($fieldValue)) continue;
+				$params[] = $fieldValue;
+				$queryStr .= ', ' . $fieldName;
+				$otherValueStr .= ', ?';
+			}
+		}
+		$queryStr .=   ') VALUES ';
+		$queryStr .=   '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?' . $otherValueStr . ')';
+		$this->execStatement($queryStr, $params);
 
 		// 新規のシリアル番号取得
 		$newSerial = 0;
-		$queryStr = 'select max(be_serial) as ns from blog_entry ';
+		$queryStr = 'SELECT MAX(be_serial) AS ns FROM blog_entry ';
 		$ret = $this->selectRecord($queryStr, array(), $row);
 		if ($ret) $newSerial = $row['ns'];
 		
@@ -531,7 +595,7 @@ class blog_mainDb extends BaseDb
 		// 指定のシリアルNoのレコードが削除状態でないかチェック
 		$queryStr  = 'SELECT * FROM blog_entry ';
 		$queryStr .=   'WHERE be_serial = ? ';
-		$ret = $this->selectRecord($queryStr, array($serial), $row);
+		$ret = $this->selectRecord($queryStr, array(intval($serial)), $row);
 		if ($ret){		// 既に登録レコードがあるとき
 			if ($row['be_deleted']){		// レコードが削除されていれば終了
 				$this->endTransaction();
@@ -547,7 +611,7 @@ class blog_mainDb extends BaseDb
 		$queryStr .=     'be_update_user_id = ?, ';
 		$queryStr .=     'be_update_dt = ? ';
 		$queryStr .=   'WHERE be_serial = ?';
-		$this->execStatement($queryStr, array($now, $userId, $now, $serial));
+		$this->execStatement($queryStr, array($now, $userId, $now, intval($serial)));
 		
 		// トランザクション確定
 		$ret = $this->endTransaction();
@@ -571,7 +635,7 @@ class blog_mainDb extends BaseDb
 		$queryStr .=  'bw_category_id) ';
 		$queryStr .=  'VALUES ';
 		$queryStr .=  '(?, ?, ?)';
-		$ret =$this->execStatement($queryStr, array($serial, $index, $categoryId));
+		$ret =$this->execStatement($queryStr, array(intval($serial), $index, $categoryId));
 		return $ret;
 	}
 	/**
@@ -587,14 +651,14 @@ class blog_mainDb extends BaseDb
 		$queryStr  = 'select *,reg.lu_name as reg_user_name from blog_entry LEFT JOIN _login_user ON be_create_user_id = lu_id AND lu_deleted = false ';
 		$queryStr .=   'LEFT JOIN _login_user as reg ON be_regist_user_id = reg.lu_id AND reg.lu_deleted = false ';
 		$queryStr .=   'WHERE be_serial = ? ';
-		$ret = $this->selectRecord($queryStr, array($serial), $row);
+		$ret = $this->selectRecord($queryStr, array(intval($serial)), $row);
 		
 		if ($ret){
 			// ブログカテゴリー
 			$queryStr  = 'SELECT * FROM blog_entry_with_category LEFT JOIN blog_category ON bw_category_id = bc_id AND bc_deleted = false ';
 			$queryStr .=   'WHERE bw_entry_serial = ? ';
 			$queryStr .=  'ORDER BY bw_index ';
-			$this->selectRecords($queryStr, array($serial), $categoryRow);
+			$this->selectRecords($queryStr, array(intval($serial)), $categoryRow);
 		}
 		return $ret;
 	}
@@ -659,14 +723,14 @@ class blog_mainDb extends BaseDb
 	/**
 	 * エントリーIDでエントリー項目を削除
 	 *
-	 * @param array   $serial		シリアルNo
+	 * @param int   $serial			シリアルNo
 	 * @return						true=成功、false=失敗
 	 */
 	function delEntryItemById($serial)
 	{
 		// 引数のエラーチェック
-		if (!is_array($serial)) return false;
-		if (count($serial) <= 0) return true;
+//		if (!is_array($serial)) return false;
+//		if (count($serial) <= 0) return true;
 		
 		$now = date("Y/m/d H:i:s");	// 現在日時
 		$userId = $this->gEnv->getCurrentUserId();	// 現在のユーザ
@@ -678,7 +742,7 @@ class blog_mainDb extends BaseDb
 		$queryStr  = 'select * from blog_entry ';
 		$queryStr .=   'where be_deleted = false ';		// 未削除
 		$queryStr .=     'and be_serial = ? ';
-		$ret = $this->selectRecord($queryStr, array($serial), $row);
+		$ret = $this->selectRecord($queryStr, array(intval($serial)), $row);
 		if ($ret){		// 既に登録レコードがあるとき
 			if ($row['be_deleted']){		// レコードが削除されていれば終了
 				$this->endTransaction();
@@ -705,18 +769,37 @@ class blog_mainDb extends BaseDb
 	/**
 	 * エントリー項目を取得
 	 *
-	 * @param int		$id					エントリーID
+	 * @param int,array		$id				エントリーID
 	 * @param string	$langId				言語
 	 * @param array     $row				レコード
 	 * @return bool							取得 = true, 取得なし= false
 	 */
 	function getEntryItem($id, $langId, &$row)
 	{
-		$queryStr  = 'SELECT * FROM blog_entry LEFT JOIN blog_id ON be_blog_id = bl_id AND bl_deleted = false ';
-		$queryStr .=   'WHERE be_deleted = false ';	// 削除されていない
-		$queryStr .=   'AND be_id = ? ';
-		$queryStr .=   'AND be_language_id = ? ';
-		$ret = $this->selectRecord($queryStr, array($id, $langId), $row);
+		if (is_array($id)){
+			$params = array();
+			$contentId = implode(',', $id);
+		
+			// CASE文作成
+			$caseStr = 'CASE be_id ';
+			for ($i = 0; $i < count($id); $i++){
+				$caseStr .= 'WHEN ' . $id[$i] . ' THEN ' . $i . ' ';
+			}
+			$caseStr .= 'END AS no';
+
+			$queryStr = 'SELECT *, ' . $caseStr . ' FROM blog_entry LEFT JOIN blog_id ON be_blog_id = bl_id AND bl_deleted = false ';
+			$queryStr .=  'WHERE be_deleted = false ';		// 削除されていない
+			$queryStr .=    'AND be_id in (' . $contentId . ') ';
+			$queryStr .=    'AND be_language_id = ? '; $params[] = $langId;
+			$queryStr .=  'ORDER BY no';
+			$ret = $this->selectRecords($queryStr, $params, $row);
+		} else {
+			$queryStr  = 'SELECT * FROM blog_entry LEFT JOIN blog_id ON be_blog_id = bl_id AND bl_deleted = false ';
+			$queryStr .=   'WHERE be_deleted = false ';	// 削除されていない
+			$queryStr .=   'AND be_id = ? ';
+			$queryStr .=   'AND be_language_id = ? ';
+			$ret = $this->selectRecord($queryStr, array($id, $langId), $row);
+		}
 		return $ret;
 	}
 	/**
@@ -744,6 +827,7 @@ class blog_mainDb extends BaseDb
 		// エントリーIDの指定がない場合は、期間で取得
 		if (empty($entryId)){
 			$queryStr  = 'SELECT * FROM blog_entry LEFT JOIN blog_id ON be_blog_id = bl_id AND bl_deleted = false ';
+			$queryStr .=   'LEFT JOIN _login_user ON be_regist_user_id = lu_id AND lu_deleted = false ';
 			$queryStr .=   'WHERE be_deleted = false ';		// 削除されていない
 			$queryStr .=     'AND be_status = ? ';		$params[] = 2;	// 「公開」(2)データを表示
 			$queryStr .=     'AND be_language_id = ? ';	$params[] = $langId;
@@ -781,6 +865,7 @@ class blog_mainDb extends BaseDb
 		} else {
 			//$queryStr = 'SELECT * FROM blog_entry ';
 			$queryStr  = 'SELECT * FROM blog_entry LEFT JOIN blog_id ON be_blog_id = bl_id AND bl_deleted = false ';
+			$queryStr .=   'LEFT JOIN _login_user ON be_regist_user_id = lu_id AND lu_deleted = false ';
 			$queryStr .=   'WHERE be_deleted = false ';		// 削除されていない
 			$queryStr .=     'AND be_status = ? ';	$params[] = 2;	// 「公開」(2)データを表示
 			$queryStr .=     'AND be_id = ? ';		$params[] = $entryId;
@@ -899,8 +984,8 @@ class blog_mainDb extends BaseDb
 		$serialStr = implode(',', $serialArray);
 		if (empty($serialStr)) $serialStr = '0';	// 0レコードのときはダミー値を設定
 	
-		//$queryStr = 'SELECT * FROM blog_entry ';
 		$queryStr  = 'SELECT * FROM blog_entry LEFT JOIN blog_id ON be_blog_id = bl_id AND bl_deleted = false ';
+		$queryStr .=   'LEFT JOIN _login_user ON be_regist_user_id = lu_id AND lu_deleted = false ';
 		$queryStr .=   'WHERE be_serial in (' . $serialStr . ') ';
 		$ord = '';
 		if (!empty($order)) $ord = 'DESC ';
@@ -992,7 +1077,7 @@ class blog_mainDb extends BaseDb
 		$queryStr .=   'WHERE be_deleted = false ';		// 削除されていない
 		$queryStr .=     'AND be_serial = ? ';
 		$queryStr .=     'AND be_blog_id = ? ';
-		return $this->isRecordExists($queryStr, array($serial, $blogId));
+		return $this->isRecordExists($queryStr, array(intval($serial), $blogId));
 	}
 	/**
 	 * コメントが指定ブログ属するかチェック
@@ -1008,7 +1093,7 @@ class blog_mainDb extends BaseDb
 		$queryStr .=   'WHERE bo_deleted = false ';		// 削除されていない
 		$queryStr .=     'AND bo_serial = ? ';
 		$queryStr .=     'AND be_blog_id = ? ';
-		return $this->isRecordExists($queryStr, array($serial, $blogId));
+		return $this->isRecordExists($queryStr, array(intval($serial), $blogId));
 	}
 	/**
 	 * すべてのブログIDを取得
@@ -1063,7 +1148,7 @@ class blog_mainDb extends BaseDb
 	{
 		$queryStr  = 'SELECT * FROM blog_id LEFT JOIN _login_user ON bl_create_user_id = lu_id AND lu_deleted = false ';
 		$queryStr .=   'WHERE bl_serial = ? ';
-		$ret = $this->selectRecord($queryStr, array($serial), $row);
+		$ret = $this->selectRecord($queryStr, array(intval($serial)), $row);
 		return $ret;
 	}
 	/**
@@ -1124,7 +1209,7 @@ class blog_mainDb extends BaseDb
 			// 指定のシリアルNoのレコードが削除状態でないかチェック
 			$queryStr  = 'SELECT * FROM blog_id ';
 			$queryStr .=   'WHERE bl_serial = ? ';
-			$ret = $this->selectRecord($queryStr, array($serial), $row);
+			$ret = $this->selectRecord($queryStr, array(intval($serial)), $row);
 			if ($ret){		// 既に登録レコードがあるとき
 				if ($row['bl_deleted']){		// レコードが削除されていれば終了
 					$this->endTransaction();
@@ -1146,7 +1231,7 @@ class blog_mainDb extends BaseDb
 			$queryStr .=     'bl_update_user_id = ?, ';
 			$queryStr .=     'bl_update_dt = ? ';
 			$queryStr .=   'WHERE bl_serial = ?';
-			$ret = $this->execStatement($queryStr, array($userId, $now, $serial));
+			$ret = $this->execStatement($queryStr, array($userId, $now, intval($serial)));
 			if (!$ret){
 				$this->endTransaction();
 				return false;
@@ -1269,5 +1354,44 @@ class blog_mainDb extends BaseDb
 		$queryStr .=   'ORDER BY lu_user_type, lu_account';
 		$this->selectLoop($queryStr, array($minLevel), $callback);
 	}
+	/**
+	 * ブログ記事履歴を取得
+	 *
+	 * @param string	$entryId			記事ID
+	 * @param string	$langId				言語
+	 * @param int		$limit				取得する項目数
+	 * @param int		$page				取得するページ(1～)
+	 * @param function	$callback			コールバック関数
+	 * @return 			なし
+	 */
+	function getEntryHistory($entryId, $langId, $limit, $page, $callback)
+	{
+		$offset = $limit * ($page -1);
+		if ($offset < 0) $offset = 0;
+		
+		$params = array();
+		$queryStr = 'SELECT * FROM blog_entry LEFT JOIN _login_user ON be_create_user_id = lu_id AND lu_deleted = false ';
+		$queryStr .=  'WHERE be_id = ? ';$params[] = $entryId;
+		$queryStr .=    'AND be_language_id = ? ';$params[] = $langId;
+		$queryStr .=  'ORDER BY be_history_index ';
+		$queryStr .=    'DESC ';
+		$queryStr .=  'LIMIT ' . $limit . ' OFFSET ' . $offset;
+		$this->selectLoop($queryStr, $params, $callback);
+	}
+	/**
+	 * ブログ記事履歴数を取得
+	 *
+	 * @param string	$entryId			記事ID
+	 * @param string	$langId				言語
+	 * @return int							項目数
+	 */
+	function getEntryHistoryCount($entryId, $langId)
+	{
+		$params = array();
+		$queryStr = 'SELECT * FROM blog_entry LEFT JOIN _login_user ON be_create_user_id = lu_id AND lu_deleted = false ';
+		$queryStr .=  'WHERE be_id = ? ';$params[] = $entryId;
+		$queryStr .=    'AND be_language_id = ? ';$params[] = $langId;
+		return $this->selectRecordCount($queryStr, $params);
+	}
 }
 ?>
