@@ -11,7 +11,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: index.php 3953 2011-01-24 04:33:43Z fishbone $
+ * @version    SVN: $Id: index.php 5157 2012-09-05 06:41:45Z fishbone $
  * @link       http://www.magic3.org
  */
 // 直接アクセスの防止
@@ -167,5 +167,5 @@ $HELP['config_receive_comment']['body'] = 'ブログ記事に対して、ユー
 $HELP['config_max_comment_length']['title'] = '最大文字数';
 $HELP['config_max_comment_length']['body'] = 'コメントに入力可能な文字数を設定します。0を指定した場合は無制限です。';
 $HELP['config_multi_blog_top_content']['title'] = 'マルチブログトップコンテンツ';
-$HELP['config_multi_blog_top_content']['body'] = 'マルチブログを使用した場合のトップ画面のコンテンツです。';
+$HELP['config_multi_blog_top_content']['body'] = 'マルチブログを使用した場合のトップ画面のコンテンツです。各ブログへのリンク等を設定します。空文字列を設定した場合は全ブログのブログ記事が一覧表示されます。';
 ?>
