@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_default_contentContentWidgetContainer.php 5118 2012-08-18 09:01:17Z fishbone $
+ * @version    SVN: $Id: admin_default_contentContentWidgetContainer.php 5143 2012-08-27 13:39:55Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getWidgetContainerPath('default_content') . '/admin_default_contentBaseWidgetContainer.php');
@@ -158,6 +158,7 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 						$newInfoObj = new stdClass;
 						$newInfoObj->contentId = $row['cn_id'];		// コンテンツID
 						$newInfoObj->name = $row['cn_name'];		// コンテンツ名前
+						$newInfoObj->thumb = $row['cn_thumb_filename'];		// サムネール
 						$delContentInfo[] = $newInfoObj;
 					}
 				}
@@ -169,10 +170,17 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 				//	$ret = self::$_mainDb->delContentItem($delItems);
 				//}
 				
-				// ##### 添付ファイルをコンテンツIDで削除 #####
 				if ($ret){
 					for ($i = 0; $i < count($delContentInfo); $i++){
 						$infoObj = $delContentInfo[$i];
+						
+						// サムネールを削除
+						if (!empty($infoObj->thumb)){
+							$oldFiles = explode(';', $infoObj->thumb);
+							$this->gInstance->getImageManager()->delSystemDefaultThumb(M3_VIEW_TYPE_CONTENT, default_contentCommonDef::$_deviceType, $oldFiles);
+						}
+						
+						// 添付ファイルをコンテンツIDで削除
 						$ret = $this->gInstance->getFileManager()->delAttachFileInfoByContentId(default_contentCommonDef::$_viewContentType,
 																								$infoObj->contentId, default_contentCommonDef::getAttachFileDir());
 						if (!$ret) break;
@@ -343,7 +351,7 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 
 		$reloadData = false;		// データの再読み込み
 		$hasPassword = false;		// パスワードが設定されているかどうか
-		$histryIndex = -1;	// 履歴番号
+		$historyIndex = -1;	// 履歴番号
 		if ($act == 'add'){		// 項目追加の場合。多言語対応の場合はデフォルト言語が最初に追加される。
 			// 入力チェック
 			$this->checkInput($name, '名前');
@@ -682,7 +690,7 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 				if (!empty($row['cn_password'])) $hasPassword = true;		// パスワードが設定されている
 				
 				// 履歴番号
-				if ($row['cn_deleted']) $histryIndex = $row['cn_history_index'];
+				if ($row['cn_deleted']) $historyIndex = $row['cn_history_index'];
 				
 				// ユーザ定義フィールド
 				$this->fieldValueArray = $this->unserializeArray($row['cn_option_fields']);
@@ -801,7 +809,7 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 				$previewUrl = $this->gEnv->getDefaultSmartphoneUrl() . '?' . M3_REQUEST_PARAM_CONTENT_ID . '=' . $contentId;
 				break;
 		}
-		if ($histryIndex >= 0) $previewUrl .= '&' . M3_REQUEST_PARAM_HISTORY . '=' . $histryIndex;
+		if ($historyIndex >= 0) $previewUrl .= '&' . M3_REQUEST_PARAM_HISTORY . '=' . $historyIndex;
 		$previewUrl .= '&' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_PREVIEW;
 		if ($this->isMultiLang) $previewUrl .= '&' . M3_REQUEST_PARAM_OPERATION_LANG . '=' . $this->langId;		// 多言語対応の場合は言語IDを付加
 		$this->tmpl->addVar('_widget', 'preview_url', $previewUrl);// プレビュー用URL(一般画面)
@@ -845,7 +853,7 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 		} else {
 			// 履歴番号
 			$itemId = $contentId;			// コンテンツID
-			if ($histryIndex >= 0) $itemId .= '(' . ($histryIndex +1) . ')';
+			if ($historyIndex >= 0) $itemId .= '(' . ($historyIndex +1) . ')';
 
 			$this->tmpl->addVar("_widget", "sel_item_id", $contentId);			// コンテンツID
 			$this->tmpl->addVar("_widget", "item_id", $itemId);			// コンテンツID
