@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2009 Magic3 Project.
+ * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_ec_mainOrderWidgetContainer.php 2260 2009-08-27 05:59:32Z fishbone $
+ * @version    SVN: $Id: admin_ec_mainOrderWidgetContainer.php 4185 2011-06-11 14:47:51Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_ec_mainBaseWidgetContainer.php');
@@ -497,6 +497,7 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 		$this->tmpl->addVar("_widget", "serial", $this->serialNo);
 		$this->tmpl->addVar("_widget", "admin_url", $this->getUrl($this->gEnv->getDefaultAdminUrl()));
 		$this->tmpl->addVar('_widget', 'widget_id', $this->gEnv->getCurrentWidgetId());
+		$this->tmpl->addVar("_widget", "productid_key", M3_REQUEST_PARAM_PRODUCT_ID);		// 商品IDキー
 		//$this->tmpl->addVar('_widget', 'product_widget_id', self::TARGET_PRODUCT_WIDGET);		// 商品表示用
 	}
 	/**
@@ -629,13 +630,14 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 		$price = $prePrice . $dispPrice . $available;
 		
 		// 商品詳細へのリンク
-		$url  = '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_FIND_WIDGET;
+/*		$url  = '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_FIND_WIDGET;
 		//$url .= '&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $this->gEnv->getCurrentWidgetId();
 		$url .= '&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . self::TARGET_PRODUCT_WIDGET;
 		$url .= '&' . M3_REQUEST_PARAM_FROM . '=' . $this->gEnv->getCurrentWidgetId();		// 送信元
-		$url .= '&' . M3_REQUEST_PARAM_OPERATION_TODO . '=' . urlencode('product=' . $fetchedRow['si_product_id']);
-			
+		$url .= '&' . M3_REQUEST_PARAM_OPERATION_TODO . '=' . urlencode('product=' . $fetchedRow['si_product_id']);*/
+		$url = $this->gEnv->getDefaultUrl() . '?' . M3_REQUEST_PARAM_PRODUCT_ID . '=' . $fetchedRow['si_product_id'];
 		$nameLink = '<a href="' . $this->getUrl($url, true) . '">' . $name . '</a>';
+		
 		$row = array(
 			'line_color' => $lineColor,											// 行のカラー
 			'no' => $index + 1,													// 行番号
