@@ -8,19 +8,19 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2009 Magic3 Project.
+ * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: reg_userLoginWidgetContainer.php 2363 2009-09-26 14:45:44Z fishbone $
+ * @version    SVN: $Id: reg_userLoginWidgetContainer.php 5158 2012-09-05 07:47:37Z fishbone $
  * @link       http://www.magic3.org
  */
-require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
+//require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
+require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/reg_userBaseWidgetContainer.php');
 require_once($gEnvManager->getIncludePath() . '/common/userInfo.php');		// ユーザ情報クラス
 require_once($gEnvManager->getCurrentWidgetDbPath() .	'/reg_userDb.php');
 
-class reg_userLoginWidgetContainer extends BaseWidgetContainer
+class reg_userLoginWidgetContainer extends reg_userBaseWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
-	private $sysDb;		// システムDBオブジェクト
 	const REGIST_USER_COMPLETED_FORM = 'regist_user_completed';		// メールフォーム
 	const DEFAULT_PASSWORD = '********';	// 設定済みを示すパスワード
 	
@@ -34,7 +34,6 @@ class reg_userLoginWidgetContainer extends BaseWidgetContainer
 		
 		// DB接続オブジェクト作成
 		$this->db = new reg_userDb();
-		$this->sysDb = $this->gInstance->getSytemDbObject();
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -65,23 +64,16 @@ class reg_userLoginWidgetContainer extends BaseWidgetContainer
 		if (!empty($paramObj)){
 			$this->authType	= $paramObj->authType;			// 承認タイプ
 		}
-		if (empty($this->authType)){
-			return;			// 承認タイプが設定されていないときは終了
-		}
+		if (empty($this->authType)) return;		// 承認タイプが設定されていないときは終了
 				
 		$act = $request->trimValueOf('act');
 		// ユーザ自動認証のときのみ処理を実行
-		if ($this->authType != 'auto') return;
-		
+//		if ($this->authType != 'auto') return;
+
 		if ($act == 'user_maillogin'){		// メールからのログイン画面の表示
 			$account = $request->trimValueOf('account');
 			$pwd = $request->trimValueOf('pwd');
 			
-			// ハッシュキー作成
-			$postTicket = md5(time() . $this->gAccess->getAccessLogSerialNo());
-			$request->setSessionValue(M3_SESSION_POST_TICKET, $postTicket);		// セッションに保存
-			
-			$this->tmpl->addVar("_widget", "ticket", $postTicket);				// 画面に書き出し
 			$this->tmpl->addVar("_widget", "user_account", $account);
 			$this->tmpl->addVar("_widget", "user_password", $pwd);
 		} else if ($act == 'user_login'){			// 会員ログインのとき
@@ -97,8 +89,8 @@ class reg_userLoginWidgetContainer extends BaseWidgetContainer
 					// 未承認ユーザから一般ユーザへ変更
 					$userId = $this->gEnv->getCurrentUserId();
 					if ($userId != 0){
-						if (!$this->sysDb->isAuthenticatedUser($userId)){		// 未承認のときのみ承認作業を行う
-							$ret = $this->sysDb->makeNormalLoginUser($userId);// 一般ログインユーザに設定
+						if (!$this->_db->isAuthenticatedUser($userId)){		// 未承認のときのみ承認作業を行う
+							$ret = $this->_db->makeNormalLoginUser($userId);// 一般ログインユーザに設定
 							if ($ret){
 								$fromAddress = '';			// 管理者宛メールアドレス
 								if (empty($fromAddress)) $fromAddress = $this->gEnv->getSiteEmail();// 送信元が取得できないときは、システムのデフォルトメールアドレスを使用
@@ -132,7 +124,12 @@ class reg_userLoginWidgetContainer extends BaseWidgetContainer
 				$this->tmpl->addVar("_widget", "password_disabled", 'disabled');
 				$this->tmpl->addVar("_widget", "login_disabled", 'disabled');// 送信ボタン
 			}
+			$request->unsetSessionValue(M3_SESSION_POST_TICKET);		// セッション値をクリア
 		}
+		// ハッシュキー作成
+		$postTicket = md5(time() . $this->gAccess->getAccessLogSerialNo());
+		$request->setSessionValue(M3_SESSION_POST_TICKET, $postTicket);		// セッションに保存
+		$this->tmpl->addVar("_widget", "ticket", $postTicket);				// 画面に書き出し
 	}
 }
 ?>
